@@ -1,4 +1,10 @@
-from .aleph_alpha_client import AlephAlphaClient, QuotaError, POOLING_OPTIONS
+from .aleph_alpha_client import (
+    AlephAlphaClient,
+    QuotaError,
+    POOLING_OPTIONS,
+    AsyncClient,
+    Client,
+)
 from .aleph_alpha_model import AlephAlphaModel
 from .image import ImagePrompt
 from .prompt import Prompt
@@ -16,6 +22,7 @@ from .evaluation import EvaluationRequest, EvaluationResponse
 from .tokenization import TokenizationRequest, TokenizationResponse
 from .detokenization import DetokenizationRequest, DetokenizationResponse
 from .summarization import SummarizationRequest, SummarizationResponse
+from .search import SearchRequest, SearchResponse, SearchResult
 from .utils import load_base64_from_url, load_base64_from_file
 from .document import Document
 from .version import __version__
