@@ -1,5 +1,6 @@
 from collections import ChainMap
 from typing import Any, Mapping, Optional, Union
+import warnings
 from aleph_alpha_client.aleph_alpha_client import AlephAlphaClient
 from aleph_alpha_client.completion import CompletionRequest, CompletionResponse
 from aleph_alpha_client.detokenization import (
@@ -54,7 +55,11 @@ class AlephAlphaModel:
 
                 Need to set exactly one of model_name and checkpoint_name.
         """
-
+        warnings.warn(
+            "AlephAlphaModel is deprecated and will be removed in the next major release. Use Client or AsyncClient instead.",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         if (model_name is None and checkpoint_name is None) or (
             model_name is not None and checkpoint_name is not None
         ):
@@ -67,9 +72,10 @@ class AlephAlphaModel:
         self.hosting = hosting
         self.checkpoint_name = checkpoint_name
 
-
     @classmethod
-    def from_model_name(cls, model_name: str, token: str, hosting: Optional[str]=None):
+    def from_model_name(
+        cls, model_name: str, token: str, hosting: Optional[str] = None
+    ):
         """
         Construct a context object for a specific model.
 
@@ -84,11 +90,23 @@ class AlephAlphaModel:
             our own datacenters and on servers hosted with other providers. Choose this option for
             maximal availability. Setting it to "aleph-alpha" allows us to only process the request
             in our own datacenters. Choose this option for maximal data privacy.
+
+        Examples
+        >>> model = AlephAlphaModel.from_model_name(
+                model_name = "luminous-extended",
+                token=os.getenv("AA_TOKEN")
+            )
         """
         client = AlephAlphaClient(token=token)
         return cls(client=client, model_name=model_name, hosting=hosting)
 
     def complete(self, request: CompletionRequest) -> CompletionResponse:
+        """
+        Examples
+            >>> prompt = Prompt(["Provide a short description of AI:"])
+            >>> request = CompletionRequest(prompt=prompt, maximum_tokens=20)
+            >>> result = model.complete(request)
+        """
         response_json = self.client.complete(
             model=self.model_name,
             hosting=self.hosting,
@@ -98,7 +116,9 @@ class AlephAlphaModel:
         return CompletionResponse.from_json(response_json)
 
     def tokenize(self, request: TokenizationRequest) -> TokenizationResponse:
-        response_json = self.client.tokenize(model=self.model_name, **request._asdict(), checkpoint=self.checkpoint_name)
+        response_json = self.client.tokenize(
+            model=self.model_name, **request._asdict(), checkpoint=self.checkpoint_name
+        )
         return TokenizationResponse.from_json(response_json)
 
     def detokenize(self, request: DetokenizationRequest) -> DetokenizationResponse:
@@ -128,6 +148,11 @@ class AlephAlphaModel:
         return SemanticEmbeddingResponse.from_json(response_json)
 
     def evaluate(self, request: EvaluationRequest) -> EvaluationResponse:
+        """
+        Examples
+            >>> request = EvaluationRequest(prompt=Prompt.from_text("The api works"), completion_expected=" well")
+            >>> result = model.evaluate(request)
+        """
         response_json = self.client.evaluate(
             model=self.model_name,
             hosting=self.hosting,
