@@ -1,6 +1,6 @@
 from typing import Any, Dict, List, Mapping, NamedTuple, Optional, Sequence
 
-from aleph_alpha_client.prompt import Prompt
+from aleph_alpha_client.prompt import Prompt, _to_serializable_prompt
 
 
 class CompletionRequest(NamedTuple):
@@ -106,6 +106,10 @@ class CompletionRequest(NamedTuple):
             We continually research optimal ways to work with our models. By default, we apply these optimizations to both your prompt and  completion for you.
 
             Our goal is to improve your results while using our API. But you can always pass disable_optimizations: true and we will leave your prompt and completion untouched.
+
+    Examples
+        >>> prompt = Prompt.from_text("Provide a short description of AI:")
+        >>> request = CompletionRequest(prompt=prompt, maximum_tokens=20)
     """
 
     prompt: Prompt
@@ -128,6 +132,11 @@ class CompletionRequest(NamedTuple):
     tokens: bool = False
     disable_optimizations: bool = False
 
+    def to_json(self) -> Dict[str, Any]:
+        payload = self._asdict()
+        payload["prompt"] = _to_serializable_prompt(self.prompt.items)
+        return payload
+
 
 class CompletionResult(NamedTuple):
     log_probs: Optional[Sequence[Mapping[str, Optional[float]]]] = None
