@@ -1,5 +1,14 @@
-from typing import Any, Dict, List, NamedTuple, Optional, Sequence, Tuple, Union
-from aleph_alpha_client.prompt import Prompt
+from typing import (
+    Any,
+    Dict,
+    List,
+    NamedTuple,
+    Optional,
+    Sequence,
+    Tuple,
+    Union,
+)
+from aleph_alpha_client.prompt import Prompt, _to_serializable_prompt
 
 
 class EvaluationRequest(NamedTuple):
@@ -12,11 +21,19 @@ class EvaluationRequest(NamedTuple):
 
         completion_expected (str, required):
             The ground truth completion expected to be produced given the prompt.
+
+    Examples
+        >>> request = EvaluationRequest(prompt=Prompt.from_text("The api works"), completion_expected=" well")
     """
 
     prompt: Prompt
     completion_expected: str
 
+    def to_json(self) -> Dict[str, Any]:
+        payload = self._asdict()
+        payload["prompt"] = _to_serializable_prompt(self.prompt.items)
+        return payload
+
 
 class EvaluationResponse(NamedTuple):
     model_version: str
